==> bitcoin-0.16.2.tar.gz: bitcoin-0.16.2/src/qt/locale/bitcoin_ko.ts <==
<TS language="ko" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>마우스 오른쪽 클릭을 해서 라벨이나 주소를 편집할 수 있습니다</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>새로운 주소 발급받기</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>선택된 주소 클립보드에 붙여넣기</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;복사</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>선택한 주소 리스트에서 삭제</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>현재 탭의 데이터를 파일로 내보냅니다</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;내보내기</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;삭제하기</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>코인을 보낼 주소를 선택하세요</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>코인을 받을 주소를 선택하세요</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>보낼 주소</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>받을 주소</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>이것은 비트코인 전송을 위한 주소입니다. 코인을 보내기 전에 항상 받는 주소와 수량을 확인하세요</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>이것은 비트코인 수신을 위한 주소입니다. 코인을 받을 때 마다 항상 다른 주소를 사용 하시는 것을 권장합니다.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;주소 복사</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;편집</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>주소 목록 내보내기</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>내보내기 실패</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>주소 목록을 %1 로 저장하는 작업이 실패했습니다. 다시 시도해 주세요.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>암호문 입력</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>새 암호문</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>비밀번호 보이기</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>새 암호문을 지갑에 입력합니다. &lt;br/&gt;이러한 형식의 암호문을 사용해 주십시요.&lt;b&gt;10개 이상의 임의 문자&lt;/b&gt; 또는 &lt;b&gt;8개 이상의 단어&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>지갑 암호화</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>이 작업을 수행하려면 지갑을 잠금 해제 할 암호문이 필요합니다.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>지갑 잠금 해제</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>이 작업을 수행하려면 지갑을 복호화할 암호문이 필요합니다.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>지갑 복호화</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>암호문 변경</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>예전 암호문과 변경할 암호문을 입력하십시요.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>지갑 암호화 확인</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>경고: 지갑이 암호화된 상태로 당신의 암호문을 잃어버리셨다면, 당신은 &lt;b&gt;모든 비트코인을 잃게됩니다&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>진짜로 지갑을 암호화 할까요?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>지갑 암호화</translation>
    </message>
    <message>
        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>%1 이(가) 암호화 작업을 위해 종료됩니다. 이 암호화 작업이 바이러스로부터 비트코인을 완전히 지키지 못한다는 점을 기억하십시요.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>중요: 예전에 만들었던 모든 백업 파일은 새로 만들어진 암호화된 지갑 파일으로 교체됩니다. 보안을 위해서 예전에 만들었던 암호화 되지 않은 백업 파일은 당신이 새로 암호화된 지갑을 사용하고 사용할 수 없게 됩니다. </translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>지갑 암호화 실패</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>내부 오류로 인해 지갑 암호화가 실패했습니다. 지갑이 암호화 되지 않았습니다.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>입력한 암호문이 일치하지 않습니다.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>지갑 잠금 해제 실패</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>지갑 복호화를 위한 암호문이 일치하지 않습니다.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>지갑 복호화 실패</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>지갑 암호문이 성공적으로 변경되었습니다.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>주의: Caps Lock이 켜져있습니다!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>네트워크와 동기화중...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;개요</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>노드</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>지갑의 일반적인 개요 표시</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;거래</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>거래 기록 보기</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>애플리케이션 종료</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;%1에 대해</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1에 대한 정보 표시</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt에 대해</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Qt에 대한 정보 표시</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;설정...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>%1에 대한 구성 수정</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;지갑 암호화...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;지갑 백업...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;암호문 변경...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;보낼 주소...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;받을 주소...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>클릭해서 네트워크 활동 중지</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>네트워크 활동 중지</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>클릭해서 네트워크 활동 활성화</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>헤더 동기화 (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>디스크에서 블럭 불러오는 중</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>비트코인 주소로 코인 보내기</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>이 지갑을 다른 곳으로 백업</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Failed</source>
        <translation>내보내기 실패</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;내보내기</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>현재 탭의 데이터를 파일로 내보냅니다</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>송금액은 마이너스가 될 수 없습니다</translation>
    </message>
    </context>
</TS>

==> bitcoin-0.18.1.tar.gz: bitcoin-0.18.1/src/qt/locale/bitcoin_ko.ts <==
<TS language="ko" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>마우스 오른쪽 클릭을 해서 라벨이나 주소를 편집할 수 있습니다</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>새로운 주소 발급받기</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;발급받기</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>선택된 주소 클립보드에 붙여넣기</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;복사</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;닫기</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>선택한 주소 리스트에서 삭제</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>검색할 주소나 라벨을 입력하세요</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>현재 탭의 데이터를 파일로 내보냅니다</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;내보내기</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;삭제하기</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>코인을 보낼 주소를 선택하세요</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>코인을 받을 주소를 선택하세요</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;선택하기</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>보낼 주소</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>받을 주소</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>이것은 비트코인 전송을 위한 주소입니다. 코인을 보내기 전에 항상 받는 주소와 수량을 확인하세요</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>이것은 비트코인 수신을 위한 주소입니다. 코인을 받을 때 마다 항상 다른 주소를 사용 하시는 것을 권장합니다.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;주소 복사</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>&amp;라벨 복사</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;편집</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>주소 목록 내보내기</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>내보내기 실패</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>주소 목록을 %1 로 저장하는 작업이 실패했습니다. 다시 시도해 주세요.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>암호문 입력</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>새 암호문</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>새 암호문 다시 입력</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>비밀번호 보이기</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>새 암호문을 지갑에 입력합니다. &lt;br/&gt;이러한 형식의 암호문을 사용해 주십시요.&lt;b&gt;10개 이상의 임의 문자&lt;/b&gt; 또는 &lt;b&gt;8개 이상의 단어&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>지갑 암호화</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>이 작업을 수행하려면 지갑을 잠금 해제 할 암호문이 필요합니다.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>지갑 잠금 해제</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>이 작업을 수행하려면 지갑을 복호화할 암호문이 필요합니다.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>지갑 복호화</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>암호문 변경</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>예전 암호문과 변경할 암호문을 입력하십시요.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>지갑 암호화 확인</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>경고: 지갑이 암호화된 상태로 당신의 암호문을 잃어버리셨다면, 당신은 &lt;b&gt;모든 비트코인을 잃게됩니다&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>진짜로 지갑을 암호화 할까요?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>지갑 암호화</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>중요: 예전에 만들었던 모든 백업 파일은 새로 만들어진 암호화된 지갑 파일으로 교체됩니다. 보안을 위해서 예전에 만들었던 암호화 되지 않은 백업 파일은 당신이 새로 암호화된 지갑을 사용하고 사용할 수 없게 됩니다. </translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>지갑 암호화 실패</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>내부 오류로 인해 지갑 암호화가 실패했습니다. 지갑이 암호화 되지 않았습니다.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>입력한 암호문이 일치하지 않습니다.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>지갑 잠금 해제 실패</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>지갑 복호화를 위한 암호문이 일치하지 않습니다.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>지갑 복호화 실패</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>지갑 암호문이 성공적으로 변경되었습니다.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>주의: Caps Lock이 켜져있습니다!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>특정 시점까지 차단</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;메시지에 서명하기...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>네트워크와 동기화중...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;개요</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>지갑의 일반적인 개요 표시</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;거래</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>거래 기록 보기</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;나가기</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>애플리케이션 종료</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;%1에 대해</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1에 대한 정보 표시</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt에 대해</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Qt에 대한 정보 표시</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;설정...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>%1에 대한 구성 수정</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;지갑 암호화...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;지갑 백업...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;암호문 변경...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>&amp;URL 열기</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>지갑:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>클릭해서 네트워크 활동 중지</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>네트워크 활동 중지</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>클릭해서 네트워크 활동 활성화</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>헤더 동기화 (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>디스크에서 블럭 불러오는 중</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>비트코인 주소로 코인 보내기</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>이 지갑을 다른 곳으로 백업</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>지갑 암호화에 사용될 암호문 바꾸기</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>기본 지갑</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Failed</source>
        <translation>내보내기 실패</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>기본 지갑</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;내보내기</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>현재 탭의 데이터를 파일로 내보냅니다</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>송금액은 마이너스가 될 수 없습니다</translation>
    </message>
    </context>
</TS>
